@@ -1,6 +1,10 @@
-use strict;
-use warnings;
-
+use strictures 2;
+use stable 0.031 'postderef';
+use experimental 'signatures';
+use if "$]" >= 5.022, experimental => 're_strict';
+no if "$]" >= 5.031009, feature => 'indirect';
+no if "$]" >= 5.033001, feature => 'multidimensional';
+no if "$]" >= 5.033006, feature => 'bareword_filehandles';
 use Dist::Zilla::Chrome::Test;
 use Dist::Zilla::Plugin::PromptIfStale;
 use Class::Method::Modifiers ();
